<?php
/**
 * Fonctions du squelette associé.
 *
 * @package SPIP\TERRITOIRES\UI
 */
if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

/**
 * Formate la valeur d'un extra en fonction de sa nature.
 *
 * @api
 *
 * @param string $extra      La nature de l'extra.
 * @param mixed  $valeur     La valeur de l'extra.
 * @param string $type_extra Le type d'extra, à savoir, `info` ou `code`.
 *
 * @return mixed Valeur de l'extra formatée.
 */
function territoire_extra_afficher_valeur(string $extra, $valeur, string $type_extra) {
	// On renvoie par défaut la valeur d'entrée
	$valeur_formatee = $valeur;

	// Seules les extras de type 'info' peuvent être formatées
	if ($type_extra === 'info') {
		if (in_array($extra, ['area', 'population'])) {
			$valeur_formatee = number_format((float) $valeur, 0, ',', '&nbsp;');
		} elseif (strpos($extra, 'date_') !== false) {
			$valeur_formatee = affdate_court($valeur);
		}
	}

	return $valeur_formatee;
}

/**
 * Détermine l'unité d'un extra en fonction de sa nature.
 *
 * @api
 *
 * @param string $extra      La nature de l'extra.
 * @param string $type_extra Le type d'extra, à savoir, `info` ou `code`.
 *
 * @return string Unité de l'extra ou vide sinon aucune.
 */
function territoire_extra_afficher_unite(string $extra, string $type_extra) : string {
	// On renvoie par défaut la valeur d'entrée
	$unite = '';

	// Seules les extras de type 'info' peuvent être formatées
	if ($type_extra === 'info') {
		if ($extra === 'area') {
			$unite = 'km<sup>2</sup>';
		} elseif ($extra === 'population') {
			$unite = 'h';
		}
	}

	return $unite;
}
